#!/usr/bin/env bash
#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
# Helper script to facilitiate bulk ingestion of the VLASS
# quicklook image cache.
#
set -o errexit -o nounset -o xtrace

VLASS_ENV=$(echo $CAPO_PROFILE | sed 's/dsoc-/vlass_/')

# Base Location:
QL_CACHE_DIR=/lustre/aoc/cluster/pipeline/$VLASS_ENV/cache/se_continuum_imaging

# Tile Directory of interest:
PROJECT_CODE=$1;shift

DIR_TO_PROCESS=${QL_CACHE_DIR}/${PROJECT_CODE}

INGEST_TILE_PATH=/lustre/aoc/cluster/pipeline/$CAPO_PROFILE/workspaces/sbin/ingest_vlass_tile.sh

#
# We need a list of the subdirectories under the tile directory,
# with the full path:
#
# Note: The grep is to avoid the rejected imaging runs
#
for tileDir in $(ls -1 ${DIR_TO_PROCESS} | grep -v QA)
do
  sh ${INGEST_TILE_PATH} ${PROJECT_CODE} ${tileDir}
  sleep 30
done
#
